import telnetlib
import sys

class PytelnetMK():

    
    def __init__(self,host,user,password):
        self.ldados = [host, user, password]

    def getConn(self):
    
        tn = telnetlib.Telnet(self.ldados[0])	
        #tn.set_debuglevel(1000)
        tn.read_until(b"Login:")
        tn.write(self.ldados[1].encode('ascii') + b"\n")
        if self.ldados[2]:
            tn.read_until(b"Password:")
            tn.write(self.ldados[2].encode('ascii') + b"\n")
            print("Connected!!!")
        return tn

    def setCmd(self,cmd):
        setcmd = self.getConn()
        setcmd.read_until(b"ik] >")
        setcmd.write(cmd.encode('ascii') + b"\r")
        setcmd.write(b"exit\n")
        print(setcmd.read_all().decode('ascii'))





from setuptools import setup
setup(

    name    =	'pytelnetMK',

    version =	'0.0.1',

    python_requires ='>=3',

    py_modules	=   ['pytelnetMK'],

    author  =	'pklarner',

    author_email    =	'pedro@preciseipostei.com.br',

    url	=   'http://www.preciseipostei.com.br',

    install_requires=['telnetlib3 >=1.0.0'],

    description	=   'Connect Mikrotik telnet server using Telnetlib ',
    
    )





